function plot_data(data, scale, image_size)
%PLOT_DATA displays image data
%   plot_data(data)
%   plot_data(data, scale)
%   plot_data(data, scale, image_size)
%
%   data is a matrix of data, in column vectors
%   scale is a range [scmin scmax] as used by imagesc
%
%   Author: David Ross

%---------------------------------------
% check the input
%---------------------------------------
%error(nargchk(1,3,nargin));

%---------------------------------------
% determine the number of plots & size
% of each image
%---------------------------------------
[D N] = size(data);

% choose the number of subplots so we can draw all
% N images in a square
subplot_size = ceil(sqrt(N));


% the range of values to plot using imagesc
scale_provided = 0;
if nargin == 1 || isempty(scale)
    scale_provided = 0;
elseif prod(size(scale)) ~= 2
    error('invalid scale');
end

% if the image size has been provided, extract the numbers of
% rows and columns,
% otherwise assume the image is square
if nargin > 2 && ~isempty(image_size)
    if prod(size(image_size)) ~= 2
        error('image size must be of the form [rows cols]');
    end

    if prod(image_size) ~= D
        error(['image size must match the dimensionality of the' ...
                'input vectors']);
    end

    img_rows = image_size(1);
    img_cols = image_size(2);
else
    img_rows = sqrt(D);
    img_cols = img_rows;
end


%---------------------------------------
% Set the figure's properties.
%---------------------------------------
set(gcf, 'NumberTitle', 'off', 'MenuBar', 'none', 'Name', 'Data');
colormap('gray');


%---------------------------------------
% draw the plots
%---------------------------------------
plot_number = 1;
for nn = 1:N
    subplot(subplot_size, subplot_size, plot_number);
    plot_number = plot_number + 1;
    img = reshape(data(:,nn), img_rows, img_cols);
    if scale_provided
	imagesc(img, scale);
    else
	imagesc(img);
    end
    set(gca, 'Visible', 'off');
    axis equal tight;
end
